package com.jty.wsxt.infrastructure.security.authentication;

import com.fasterxml.jackson.databind.ObjectMapper;
import com.jty.wsxt.infrastructure.code.ValidateCodeException;
import com.jty.wsxt.infrastructure.support.Result;
import com.jty.wsxt.infrastructure.support.ResultCode;
import org.apache.commons.lang.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.security.authentication.DisabledException;
import org.springframework.security.core.AuthenticationException;
import org.springframework.security.web.authentication.SimpleUrlAuthenticationFailureHandler;
import org.springframework.stereotype.Component;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.IOException;

/**
 * APP环境下认证失败处理器
 */
@Component("jtyAuthenticationFailureHandler")
public class JtyAuthenticationFailureHandler extends SimpleUrlAuthenticationFailureHandler {

    private Logger logger = LoggerFactory.getLogger(getClass());

    @Autowired
    private ObjectMapper objectMapper;


    @Override
    public void onAuthenticationFailure(HttpServletRequest request, HttpServletResponse response,
                                        AuthenticationException exception) throws IOException, ServletException {

        logger.info("登录失败");
        exception.printStackTrace();
        response.setStatus(HttpStatus.INTERNAL_SERVER_ERROR.value());
        response.setContentType("application/json;charset=UTF-8");
        exception.printStackTrace();
        if(StringUtils.equals(exception.getMessage(),"code_error")){
            response.getWriter().write(objectMapper.writeValueAsString(Result.failure(ResultCode.PHONE_CODE_ERROR)));
        }else if(exception instanceof ValidateCodeException){
            response.getWriter().write(objectMapper.writeValueAsString(Result.failure(ResultCode.VALIDATE_CODE_ERROR)));
        }else if(exception instanceof DisabledException){
            response.getWriter().write(objectMapper.writeValueAsString(Result.failure(ResultCode.USER_ACCOUNT_FORBIDDEN)));
        }else{
            response.getWriter().write(objectMapper.writeValueAsString(Result.failure(ResultCode.USER_LOGIN_ERROR)));
        }
    }

}