package com.jty.wsxt.infrastructure.support;

import lombok.Getter;

import java.util.ArrayList;
import java.util.List;

/**
 * 返回结果枚举类
 *
 * @author Jason
 * @since 2018/12/17 13:18
 */
@Getter
public enum ResultCode {

    /* 成功状态码 */
    SUCCESS(1, "成功"),

    CODE_ERROR(2,"代码逻辑错误"),

    /* 参数错误：10001-19999 */
    PARAM_IS_INVALID(10001, "参数无效"),
    PARAM_IS_BLANK(10002, "参数为空"),
    PARAM_TYPE_BIND_ERROR(10003, "参数类型错误"),
    PARAM_NOT_COMPLETE(10004, "参数缺失"),

    /* 用户错误：20001-29999*/
    USER_NOT_LOGGED_IN(20001, "用户未登录"),
    USER_LOGIN_ERROR(20002, "账号不存在或密码错误"),
    USER_ACCOUNT_FORBIDDEN(20003, "账号已被禁用"),
    USER_NOT_EXIST(20004, "用户不存在"),
    USER_HAS_EXISTED(20005, "用户已存在"),
    USER_HAS_NOT_PERMISSION(20006, "用户没有权限"),
    ORGANIZATION_IS_DIFFERENT(20007,"用户没有权限管理另一个机构的内容"),
    PHONE_CODE_ERROR(20008,"手机验证码错误"),
    VALIDATE_CODE_ERROR(20009,"验证码错误"),


    /* 系统错误：40001-49999 */
    SYSTEM_INNER_ERROR(40001, "系统繁忙，请稍后重试"),

    /* 数据错误：50001-599999 */
    RESULT_DATA_NONE(50001, "数据未找到"),
    DATA_IS_WRONG(50002, "数据有误"),
    DATA_ALREADY_EXISTED(50003, "数据已存在"),
    DATA_IS_COMPRESS(50004,"数据是压缩文件"),
    TYPE_IS_WRONG(50005,"类型错误"),

    /* 文档审核错误：60001-69999 */
   IS_NOT_PROOFREAD(60001,"试题还未校对"),
    IS_NOT_SIGN(60002,"试题还未打标"),
    IS_NOT_CHECK(60003,"试题还未审核"),

    /* 文档解析上传错误：60001-69999 */
    FILE_READ_WRONG(70001,"读取文件异常"),
    FILE_UPLOAD_WRONG(70002,"上传文件失败"),
    FILE_ANALYSIS_WRONG(70003,"文档解析失败"),

    /* 小题操作错误：80001-89999 */
    SMALL_ADD_WRONG(80001,"小题数量超标");


    private Integer code;

    private String message;

    ResultCode(Integer code, String message) {
        this.code = code;
        this.message = message;
    }

    public Integer code() {
        return this.code;
    }

    public String message() {
        return this.message;
    }

    public static String getMessage(String name) {
        for (ResultCode item : ResultCode.values()) {
            if (item.name().equals(name)) {
                return item.message;
            }
        }
        return name;
    }

    public static Integer getCode(String name) {
        for (ResultCode item : ResultCode.values()) {
            if (item.name().equals(name)) {
                return item.code;
            }
        }
        return null;
    }

    public void setMessage(String message){
        this.message=message;
    }

    @Override
    public String toString() {
        return this.name();
    }

    //校验重复的code值
    public static void main(String[] args) {
        ResultCode[] apiResultCodes = ResultCode.values();
        List<Integer> codeList = new ArrayList<>();
        for (ResultCode apiResultCode : apiResultCodes) {
            if (codeList.contains(apiResultCode.code)) {
                System.out.println(apiResultCode.code);
            } else {
                codeList.add(apiResultCode.code());
            }
        }
    }
}
